@@ -13,6 +13,9 @@ from alembic_utils.statement import strip_terminating_semicolon
 class PGMaterializedView(ReplaceableEntity):
     """A PostgreSQL Materialized View compatible with `alembic revision --autogenerate`
 
+    Limitations:
+        Materialized views may not have other views or materialized views that depend on them.
+
     **Parameters:**
 
     * **schema** - *str*: A SQL schema name
@@ -81,61 +84,11 @@ class PGMaterializedView(ReplaceableEntity):
 
         return sql_text(
             f"""
-            DROP MATERIALIZED VIEW {self.literal_schema}."{self.signature}";
+            DROP MATERIALIZED VIEW IF EXISTS {self.literal_schema}."{self.signature}";
             CREATE MATERIALIZED VIEW {self.literal_schema}."{self.signature}" AS {definition} WITH {"NO" if not self.with_data else ""} DATA;
         """
         )
 
-    @classmethod
-    def from_database(cls, connection, schema) -> List["PGMaterializedView"]:
-        """Get a list of all functions defined in the db"""
-        sql = sql_text(
-            f"""
-        select
-            schemaname schema_name,
-            matviewname view_name,
-            definition,
-            ispopulated is_populated
-        from
-            pg_matviews
-        where
-            schemaname not in ('pg_catalog', 'information_schema')
-            and schemaname::text = '{schema}';
-        """
-        )
-        rows = connection.execute(sql).fetchall()
-        db_views = [PGMaterializedView(x[0], x[1], x[2], with_data=x[3]) for x in rows]
-
-        for view in db_views:
-            assert view is not None
-
-        return db_views
-
-    def get_compare_identity_query(self) -> str:
-        """Return SQL string that returns 1 row for existing DB object"""
-        return f"""
-        select
-            schemaname,
-            matviewname view_name
-        from
-            pg_matviews
-        where
-            schemaname::text = '{self.schema}';
-        """
-
-    def get_compare_definition_query(self) -> str:
-        """Return SQL string that returns 1 row for existing DB object"""
-        return f"""
-        select
-            schemaname,
-            matviewname view_name,
-            definition
-        from
-	    pg_matviews
-	where
-            schemaname::text = '{self.schema}';
-        """
-
     def render_self_for_migration(self, omit_definition=False) -> str:
         """Render a string that is valid python code to reconstruct self in a migration"""
         var_name = self.to_variable_name()
@@ -148,3 +101,28 @@ class PGMaterializedView(ReplaceableEntity):
             definition={repr(escaped_definition)},
             with_data={repr(self.with_data)}
         )\n\n"""
+
+    @classmethod
+    def from_database(cls, sess, schema) -> List["PGMaterializedView"]:
+        """Get a list of all functions defined in the db"""
+        sql = sql_text(
+            f"""
+        select
+            schemaname schema_name,
+            matviewname view_name,
+            definition,
+            ispopulated is_populated
+        from
+            pg_matviews
+        where
+            schemaname not in ('pg_catalog', 'information_schema')
+            and schemaname::text like '{schema}';
+        """
+        )
+        rows = sess.execute(sql).fetchall()
+        db_views = [PGMaterializedView(x[0], x[1], x[2], with_data=x[3]) for x in rows]
+
+        for view in db_views:
+            assert view is not None
+
+        return db_views
